#!/usr/bin/env python3
import matplotlib.pyplot as plt
import matplotlib.ticker as ticker
import math
import numpy as np
from amesta import AmedasStation

#syear=None
#eyear=None
syear = 1960
eyear = 2022

sta = "Tokyo"
#
# 月のリスト
months = ["jun", "jul", "aug"]

# 作図オプションのリスト
STYLES = [
    dict(label='Jun.', color='g', width=0.6, alpha=1.0, edgecolor='k', lw=1),
    dict(label='Jul.', color='b', width=0.6, alpha=1.0, edgecolor='k', lw=1),
    dict(label='Aug.', color='aqua', width=0.6, alpha=1.0, edgecolor='k', lw=1)
]

title = "Yearly timeseries of July"

# AmedasStation Classの初期化
amedas = AmedasStation(sta)
# AmedasStation.retrieve_monメソッドを使い、降水量データを取得
prep_i = amedas.retrieve_mon("prep")
#
# データの取り出し
# 降水量(mm)
prep = list()
for n in np.arange(3):
    prep.append(prep_i.loc[syear:eyear, months[n]])

# 作図
# プロットエリアの定義
#fig, ax1 = plt.subplots()
fig = plt.figure(figsize=(6, 3))
ax = fig.add_subplot(1, 1, 1)
#
# タイトルを付ける
plt.title(title + ',' + sta)
#
#
# 棒グラフの作図
off_y = np.zeros(len(prep[0]))
for n in np.arange(3):
    index = prep[n].index
    plt.bar(index, prep[n], bottom=off_y, **STYLES[n])
    add_y = np.array(prep[n])
    off_y = off_y + add_y
    #off_y = off_y + prep[n]
# y軸の範囲とラベル
plt.ylim([0, math.ceil(off_y.max()) + 100])
plt.ylabel('Precipitation (mm)')
#
# y軸の目盛り
ax.yaxis.set_major_locator(ticker.AutoLocator())
ax.yaxis.set_minor_locator(ticker.AutoMinorLocator())
# x軸の目盛り
ax.xaxis.set_major_locator(ticker.AutoLocator())
ax.xaxis.set_minor_locator(ticker.AutoMinorLocator())
# 凡例
plt.legend(loc='best')
#
# グリッド線を描く
plt.grid(color='gray', ls=':')
# プロット範囲の調整
plt.subplots_adjust(hspace=0.8, bottom=0.2)
#
# ファイルへの書き出し
fig_fname = "Fig4-2-3.png"
plt.savefig(fig_fname, dpi=300, bbox_inches='tight')
#
plt.show()
