#!/usr/bin/env python3
import matplotlib.pyplot as plt
import matplotlib.ticker as ticker
import math
from amesta import AmedasStation

# 平均と標準偏差を計算する期間
syear = 1960
eyear = 2022

sta = "Tokyo"
#
month = "jul"

title = "Mean & SD of July Precipitation"

# AmedasStation Classの初期化
amedas = AmedasStation(sta)
# AmedasStation.retrieve_monメソッドを使い、降水量データを取得
prep_i = amedas.retrieve_mon("prep")
#
#
# データの取り出し
# 降水量(mm)
prep = prep_i.loc[syear:eyear, month]
# 平均、標準偏差の計算
prepm = prep.mean()
prepsd = prep.std()
print("mean = ", prepm)
print("SD = ", prepsd)

# 作図
# プロットエリアの定義
#fig, ax1 = plt.subplots()
fig = plt.figure(figsize=(6, 3))
ax = fig.add_subplot(1, 1, 1)
#
# タイトルを付ける
plt.title(title + ',' + sta)
#
#
# 作図範囲の設定
index = [1]
plt.xlim([0, 2])
plt.ylim([0, math.ceil(prepm + prepsd) + 50])
#
# 棒グラフ
error_config = {'ecolor': '0.3', 'capsize': 6}
#error_config = {'ecolor': 'g', 'capsize': 6}
#error_config = {'ecolor': '0.3'}
#error_config = {'capsize': 6}
plt.bar(index, prepm, yerr=prepsd, error_kw=error_config, \
   color='b', width=0.4, alpha=0.4, label='Mean Precipitation')
#
# y軸のラベル
plt.ylabel('Precipitation (mm)')
# y軸の目盛り
ax.yaxis.set_major_locator(ticker.AutoLocator())
ax.yaxis.set_minor_locator(ticker.AutoMinorLocator())
# x軸の目盛り
xlabel = str(syear) + "-" + str(eyear)
ax.set_xticks([1])
ax.set_xticklabels([xlabel])
#
# 凡例
plt.legend(loc='best')
#
# グリッド線を描く
plt.grid(color='gray', ls=':')
# プロット範囲の調整
plt.subplots_adjust(hspace=0.8, bottom=0.2)
#
# ファイルへの書き出し
fig_fname = "Fig4-2-4.png"
plt.savefig(fig_fname, dpi=300, bbox_inches='tight')
#
plt.show()
