#!/usr/bin/env python3
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.ticker as mticker
import cartopy.crs as ccrs
from cartopy.mpl.ticker import LongitudeFormatter, LatitudeFormatter

# 緯度線、経度線を描く値
dlon, dlat = 30, 30
xticks = np.arange(0, 360.1, dlon)
yticks = np.arange(-90, 90.1, dlat)
# 緯度線、経度線ラベルを描く値
dlon_lab, dlat_lab = 60, 30
xticks_lab = np.arange(0, 360.1, dlon_lab)
yticks_lab = np.arange(-90, 90.1, dlat_lab)

# プロット領域の作成
fig = plt.figure()
# cartopy呼び出し
ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree(central_longitude=180))

# 海岸線を描く
ax.coastlines()

# 経度、緯度線を描く
gl = ax.gridlines(crs=ccrs.PlateCarree(), draw_labels=False,
                  linewidth=1, linestyle=':', color='k', alpha=0.8)
gl.xlocator = mticker.FixedLocator(xticks)  # 経度線
gl.ylocator = mticker.FixedLocator(yticks)  # 緯度線

ax.set_xticks(xticks_lab, crs=ccrs.PlateCarree())  # 経度線ラベル
ax.set_yticks(yticks_lab, crs=ccrs.PlateCarree())  # 緯度線ラベル

# 目盛り線ラベルの表示形式を度数表記にする
ax.xaxis.set_major_formatter(LongitudeFormatter(zero_direction_label=True))
ax.yaxis.set_major_formatter(LatitudeFormatter())
# 目盛り線ラベルのサイズを指定
ax.axes.tick_params(labelsize=12)

# ファイルへの書き出し
fig_fname = "Fig7-5-4.png"
plt.savefig(fig_fname, dpi=300, bbox_inches='tight')
plt.show()
