#!/usr/bin/env python3
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.ticker as mticker
import matplotlib.path as mpath
import cartopy.crs as ccrs
import cartopy.feature as cfeature
from cartopy.mpl.ticker import LongitudeFormatter, LatitudeFormatter
import warnings
warnings.filterwarnings('ignore')

# 緯度線、経度線を描く値
dlon, dlat = 30, 10
xticks = np.arange(-180, 180, dlon)
yticks = np.arange(-90, 90.1, dlat)

# プロット領域の作成
fig = plt.figure()
# cartopy呼び出し
#ax = fig.add_subplot(1,1,1, projection=ccrs.PlateCarree(central_longitude=180))
# 極投影図法（南極）
ax = fig.add_subplot(1, 1, 1, projection=ccrs.SouthPolarStereo())
ax.set_extent([-180, 180, -90, -20], ccrs.PlateCarree())
ax.set_title("projection='ccrs.SouthPolarStereo'")

# 海岸線を描く
#ax.coastlines()

# 経度、緯度線を描く
gl = ax.gridlines(crs=ccrs.PlateCarree(), draw_labels=False,
                  linewidth=1, linestyle=':', color='k', alpha=0.8)
gl.xlocator = mticker.FixedLocator(xticks)  # 経度線
gl.ylocator = mticker.FixedLocator(yticks)  # 緯度線

# 陸・海・川・湖を塗り分けて描く
ax.add_feature(cfeature.LAND)
ax.add_feature(cfeature.OCEAN)
ax.add_feature(cfeature.COASTLINE, linewidth=0.8)
ax.add_feature(cfeature.LAKES)
#ax.add_feature(cfeature.LAKES, alpha=0.5)
ax.add_feature(cfeature.RIVERS)

# 図枠を円形にする
center, radius = [0.5, 0.5], 0.5
theta = np.linspace(0, 2 * np.pi, 100)
verts = np.vstack([np.sin(theta), np.cos(theta)]).T
circle = mpath.Path(verts * radius + center)
ax.set_boundary(circle, transform=ax.transAxes)

# ファイルへの書き出し
fig_fname = "Fig7-4-6.png"
plt.savefig(fig_fname, dpi=300, bbox_inches='tight')
plt.show()
