#!/usr/bin/env python3
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.ticker as mticker
import cartopy.crs as ccrs
import warnings
warnings.filterwarnings('ignore')

# プロット領域の作成（図の横幅を大きくすると省略されていたラベルが表示される）
fig = plt.figure(figsize=(8, 6))
# cartopy呼び出し
ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree(central_longitude=180))
#ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree())

# 海岸線を描く
ax.coastlines()

# 経度、緯度線を描く
gl = ax.gridlines(crs=ccrs.PlateCarree(), draw_labels=True,
                  linewidth=1, linestyle=':', color='k', alpha=0.8)
gl.xlocator = mticker.FixedLocator(np.arange(-180, 180, 30))  # 経度線
gl.ylocator = mticker.FixedLocator(np.arange(-90, 90, 30))  # 緯度線

# 上と右のラベルを消す
gl.top_labels = False
gl.right_labels = False

# ファイルへの書き出し
fig_fname = "Fig7-1-7.png"
plt.savefig(fig_fname, dpi=300, bbox_inches='tight')
plt.show()
