#!/usr/bin/env python3
import matplotlib.pyplot as plt
import matplotlib.ticker as ticker

# サンプルデータ
x = (1.0, 1.25, 1.5, 1.75, 2.0)
y = (1.5, 1.5, 1.5, 1.5, 1.5)
u = (15.0, 15.0, 0.0, -35.0, -50.0)
v = (0.0, 15.0, -15.0, 25.0, 0.0)

#
# プロットエリアの定義
fig = plt.figure(figsize=(7, 1.5))
ax = fig.add_subplot(1, 1, 1)
ax.set_xlim([0.85, 2.15])
ax.set_ylim([1.0, 2.0])

# 矢羽を描く
plt.quiver(x, y, u, v, color=['b', 'r', 'k'])

# x軸の目盛り
ax.xaxis.set_major_locator(ticker.NullLocator())
ax.xaxis.set_minor_locator(ticker.NullLocator())
# y軸の目盛り
ax.yaxis.set_major_locator(ticker.NullLocator())
ax.yaxis.set_minor_locator(ticker.NullLocator())

# 東西風速、南北風速をテキストとしてプロット
for x1, y1, u1, v1 in zip(x, y, u, v):
    name = "{s1:s}{f1:2.0f}{s2:s}{f2:2.0f}{s3:s}".format(s1="(", \
      f1=u1, s2=", ", f2=v1, s3=")")
    plt.text(x1, y1 - 0.4, name, ha='center', va='center')
    #plt.text(x1, y1-0.05, name, ha='center', va='center', fontsize=9)
    #plt.text(x1, y1-0.2, name, ha='center', va='center')
    print(x1, y1, u1, v1)

# ファイルへの書き出し
fig_fname = "Fig5-1-11.png"
plt.savefig(fig_fname, dpi=300, bbox_inches='tight')
plt.show()
