#!/usr/bin/env python3
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.ticker as ticker

# x, y軸サンプルデータ
n = 200
x = np.linspace(-10, 10, n)
y = np.linspace(-10, 10, n)

# x, y軸メッシュデータ
X, Y = np.meshgrid(x, y)
# U, Vデータ
U = -1 - X**2 + Y
V = 1 + X - Y**2
#
# プロットエリアの定義
fig = plt.figure(figsize=(5, 5))
ax = fig.add_subplot(1, 1, 1)

# 流線関数を描く
ax.streamplot(X, Y, U, V, color='k', linewidth=2, density=[0.5, 1])

# グリッド線を付ける
plt.grid(color='gray', ls='--')
# 縦横比を調整
plt.gca().set_aspect('equal')

# x軸の目盛り
ax.xaxis.set_major_locator(ticker.AutoLocator())
ax.xaxis.set_minor_locator(ticker.AutoLocator())
# y軸の目盛り
ax.yaxis.set_major_locator(ticker.AutoLocator())
ax.yaxis.set_minor_locator(ticker.AutoLocator())

# ファイルへの書き出し
fig_fname = "Fig5-5-4.png"
plt.savefig(fig_fname, dpi=300, bbox_inches='tight')
plt.show()
